API
===


Initialization
==============

:mod:`cnxdb.init`
-----------------

.. automodule:: cnxdb.init

:mod:`cnxdb.init.manifest`
--------------------------

.. automodule:: cnxdb.init.manifest


Migrations
==========

:mod:`cnxdb.migrations`
-----------------------

.. automodule:: cnxdb.migrations
